#
# spec file for package python-MapProxy
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test

%{?!python_module:%define python_module() python3-%{**}}
%define pythons python3
Name:           python-MapProxy
Version:        1.14.0
Release:        3.3
Summary:        Proxy for geospatial data
License:        Apache-2.0
URL:            http://mapproxy.org/
Group:          Development/Languages/Python
Source0:        https://files.pythonhosted.org/packages/source/M/MapProxy/MapProxy-%{version}.tar.gz
# test file missing in the sdist
Source1:        https://github.com/mapproxy/mapproxy/raw/%{version}/mapproxy/test/system/fixture/cache.gpkg
Source99:       python-MapProxy-rpmlintrc
BuildRequires:  %{python_module GDAL}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Paste}
BuildRequires:  %{python_module Shapely}
BuildRequires:  %{python_module WebTest}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module botocore}
BuildRequires:  %{python_module eventlet}
BuildRequires:  %{python_module greenlet}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module moto}
BuildRequires:  %{python_module pyproj}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis}
BuildRequires:  %{python_module requests}
BuildRequires:  libgeos_c1
BuildRequires:  proj
%endif
Requires:       libgeos_c1
Requires:       proj
Requires:       python-Pillow
Requires:       python-PyYAML
Requires:       python-Shapely
Requires:       python-gdal
Requires:       python-lxml
Requires:       (python3-pyproj if proj > 5)
Recommends:     python-Paste
Recommends:     python-Werkzeug
Recommends:     python-boto3
Recommends:     python-botocore
Recommends:     python-eventlet
Recommends:     python-greenlet
Recommends:     python-lxml
Recommends:     python-redis
Recommends:     python-requests
Recommends:     python-riak
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
MapProxy is an open source proxy for geospatial data. It caches,
accelerates and transforms data from existing map services and
serves any desktop or web GIS client.

%prep
%setup -q -n MapProxy-%{version}
cp %SOURCE1 mapproxy/test/system/fixture/
# fix wrong interpreter in test scripts
sed -i 's/env python/python3/' mapproxy/test/unit/test_client_cgi.py mapproxy/test/system/fixture/minimal_cgi.py
chmod +x mapproxy/test/system/fixture/minimal_cgi.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/mapproxy-seed
%python_clone -a %{buildroot}%{_bindir}/mapproxy-util

%check
# for local tests outside of obs
#export MAPPROXY_TEST_COUCHDB=http://127.0.0.1:5984
#export MAPPROXY_TEST_REDIS=127.0.0.1:6379
export BOTO_CONFIG=/doesnotexist
# online tests or no local server started
donttest="TestCouchDBCache"
donttest="$donttest or TestRedisCache"
donttest="$donttest or test_https_"
# off by one error capturing the execptions
donttest="$donttest or test_bad_config_geopackage_"
# https://github.com/mapproxy/mapproxy/issues/564
donttest="$donttest or test_output_formats_greyscale_png"
donttest="$donttest or test_output_formats_png8"
# flaky
donttest="$donttest or (TestWMS130 and test_get_map)"
%pytest mapproxy -ra -k "not ($donttest)"

%post
%python_install_alternative mapproxy-seed mapproxy-util

%postun
%python_uninstall_alternative mapproxy-seed

%files %{python_files}
%doc CHANGES.txt README.rst
%license COPYING.txt LICENSE.txt
%python_alternative %{_bindir}/mapproxy-seed
%python_alternative %{_bindir}/mapproxy-util
%{python_sitelib}/mapproxy
%{python_sitelib}/MapProxy-%{version}*-info

%changelog
* Sat Jun 18 2022 Ben Greiner <code@bnavigator.de>
- Skip another flaky test
* Mon Feb 28 2022 Ben Greiner <code@bnavigator.de>
- Skip failing tests due to Pillow 9
* Thu Jan 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.14.0
  * Refresh while serving (#518).
  * Enabled commandline option skip uncached (#515)
  * Several dependencies updated
  * Support for python 3.5 has been dropped because of its EOL, 3.9
    has been added
  * Several minor bugfixes
  * Security fix to avoid potential web cache poisoning.
- Remove -devel and pkgconfig build dependencies: This is a pure
  python package not using any headers
* Sat Jul 24 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.13.2
  * Hotfix: Fixup demo service (#528).
- Release 1.31.1
  * Improvement: Support cookie management for HTTP sources.
  * Security fix for local file disclosure (#526).
- Packaging:
  * add skip failing test_geotiff_tags
* Mon Apr 26 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.13.0
  * Proj: Support for PROJ>=5 via pyproj.
  * Services: New hide_exception_url option to hide source URLs.
  * Tile sources: Support '@' in URL path (e.g. /0/0/0@2x.png)
  * Various fixes for Python 3.8 compatibility.
  * WMS: Always query WMS server in supported SRS.
  * Fix warnings for tagged layer sources in layers.
  * Demo: Fix capabilites "as HTML" when running behind a proxy
- Release 1.12.0
  * Cache: Rescale tiles existing tiles with new upscale_tiles/
    downscale_tiles option.
  * Cache: Finer control for reprojection sources with
    preferred_src_proj option.
  * WMS: Add georeference to TIFF images (GeoTIFF).
  * WMS: Support for compressed TIFF images (LZW/JPEG).
  * WMS: Advertise MaxWidth/MaxHeight.
  * WMTS: Support for FeatureInfo requests.
  * WMS/ArcGIS: Add on_error handler (similar to on_error handling
    for tile sources).
  * WMS/WMTS: Add keyword_list to capabilities.
  * S3: Support for custom S3 server and ACL.
  * autoconfig: Support for username/password in URL.
  * Various fixes for Python 3.6 and 3.7 compatibility.
  * Set explicit permissions for write_atomic on Windows.
  * WMS: Respond with highest supported WMS version (1.3.0 by
    default).
  * Test: Now uses pytest instead of nosetest for all unit and
    system tests.
  * YAML: Always use load_safe to support PyYAML >3 without
    warnings.
  * Paster and eventlet specific code removed.
- Release 1.11.1
  * Fix Cross Site Scripting (XSS) issue in demo service. Fix for
    [#322] did not properly escaped input used in JavaScript
    examples. Found by Janek Vind. A targeted attack could be used
    for information disclosure. For example: Session cookies of a
    third party application running on the same domain.
- GDAL is python3 only, so do the same here.
- add python-MapProx-rpmlintrc
- Enable (offline!) test suite
- add missing cache.gpkg for tests
* Wed Mar  6 2019 Todd R <toddrme2178@gmail.com>
- Update to version 1.11.0
  + Improvements:
  * Improve reprojection performance and accuracy.
  * ArcGIS compact cache: Support for version 2.
  * ArcGIS compact cache: Improve performance for version 1.
  * ArcGIS compact cache: Add ``mapproxy-util defrag`` to reduce bundle size
    after tiles were removed/updated.
  * ArcGIS REST source: Support opts.map and seed_only.
  * Use systems CA certs by default and fix ssl_no_cert_checks
    for Python >=2.7.9 and >=3.4
  * WMS: Improve Bounding Boxes in Capabilities.
  * Mapserver: Find mapserv binary in PATH environment.
  + Fixes:
  * Seed: Always show last log line (100%%).
  * Fix saving transparent PNGs for some versions of Pillow
    (workaround for Pillow bug #2633)
  * SQLite: Fix possible errors on first request after start.
  * Demo: Fix demo client with `use_grid_names`.
  * serve-develop: Fix header encoding for Python 3.
  * Seed: Fix --interactive for Python 3.
  * Support tagged layers for sources with colons in name.
  * Support # character in Basis Authentication password.
  * Fix import error with shapely>=1.6
  * Fix duplicate level caches when using WMTS KVP with MBtile/SQLite/CouchDB.
  + Other:
  * Remove support for Python 2.6
* Fri Jul 14 2017 toddrme2178@gmail.com
- Ipmlement single-spec version
- Fix source URL.
- Rename to python-MapProxy to match openSUSE python naming
  guidelines
- Update to version 1.10.3
  * Support for S3 cache.
  * Support for the ArcGIS Compact Cache format version 1.
  * Support for GeoPackage files.
  * Support for Redis cache.
  * Support meta_tiles for tiles sources with bulk_meta_tiles option.
  * mbtiles/sqlite cache: Store multiple tiles in one transaction.
  * mbtiles/sqlite cache: Make timeout and WAL configurable.
  * ArcGIS REST source: Improve handling for ImageServer endpoints.
  * ArcGIS REST source: Support FeatureInfo requests.
  * ArcGIS REST source: Support min_res and max_res.
  * Support merging of RGB images with fixed transparency.
  * Coverages: Clip source requests at coverage boundaries.
  * Coverages: Build the difference, union or intersection of multiple coverages.
  * Coverages: Create coverages from webmercator tile coordinates like 05/182/123
    with expire tiles files.
  * Coverages: Add native support for GeoJSON (no OGR/GDAL required).
  * mapproxy-seed: Add --duration, -reseed-file and -reseed-interval options.
* Fri Jul 31 2015 tzotsos@opensuse.org
- use default python-PyYAML
* Thu Jul 30 2015 tzotsos@opensuse.org
- use default hdf-devel
* Wed Feb  4 2015 mpluskal@suse.com
- Update dependencies
* Sun Nov 30 2014 Angelos Tzotsos <tzotsos@opensuse.org>
- upgrade to 1.7.1
* Thu Sep 12 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- upgrade to 1.6.0
* Sun Nov 25 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- initial build 1.4.0
